==> pipewire-docs-1%3A0.3.33-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/pipewire_2src_2pipewire_2node_8h.js <==
var pipewire_2src_2pipewire_2node_8h =
[
    [ "pw_node_add_listener", "group__pw__node.html#ga551b316bd8df6636cd863b82d3f006e3", null ],
    [ "PW_NODE_CHANGE_MASK_ALL", "pipewire_2src_2pipewire_2node_8h.html#a7f79a67df47a08661d622c1ca73571ea", null ],
    [ "PW_NODE_CHANGE_MASK_INPUT_PORTS", "pipewire_2src_2pipewire_2node_8h.html#a111891241c623bdfe86ba5e1811f374e", null ],
    [ "PW_NODE_CHANGE_MASK_OUTPUT_PORTS", "pipewire_2src_2pipewire_2node_8h.html#a91a6a1a257b75f8a6fd5eb6755447a59", null ],
    [ "PW_NODE_CHANGE_MASK_PARAMS", "pipewire_2src_2pipewire_2node_8h.html#a13f0cb22b45e8f81e709b84ff3b1fde7", null ],
    [ "PW_NODE_CHANGE_MASK_PROPS", "pipewire_2src_2pipewire_2node_8h.html#a3db541c9ec1c2245fe17402135979f2d", null ],
    [ "PW_NODE_CHANGE_MASK_STATE", "pipewire_2src_2pipewire_2node_8h.html#a9d39e0829f4a14185dc242d5c362b9de", null ],
    [ "pw_node_enum_params", "group__pw__node.html#ga3c668f349296e6fcbf3b294b92274f1f", null ],
    [ "PW_NODE_EVENT_INFO", "group__pw__node.html#gac3a4cf514e46d1e590ad45fd3e8d7813", null ],
    [ "PW_NODE_EVENT_NUM", "group__pw__node.html#ga3c78657690ffa3263238181bbe7073e4", null ],
    [ "PW_NODE_EVENT_PARAM", "group__pw__node.html#gaf8cda535f0a1e63b1074f859cf650525", null ],
    [ "pw_node_method", "group__pw__node.html#ga8f11f362e3c9cda9d9fba69ed37f9c9b", null ],
    [ "PW_NODE_METHOD_ADD_LISTENER", "group__pw__node.html#ga027e0d76dfb4448a29d718bec066b409", null ],
    [ "PW_NODE_METHOD_ENUM_PARAMS", "group__pw__node.html#ga5437fe007ac346f48f0f63fec8ca8b40", null ],
    [ "PW_NODE_METHOD_NUM", "group__pw__node.html#ga1977da2214d00db4a4d50202da3a2c35", null ],
    [ "PW_NODE_METHOD_SEND_COMMAND", "group__pw__node.html#ga3add61d46ad7b1daa86792cbeafc6090", null ],
    [ "PW_NODE_METHOD_SET_PARAM", "group__pw__node.html#ga6b2101857ce7cd58fa7024afa281a730", null ],
    [ "PW_NODE_METHOD_SUBSCRIBE_PARAMS", "group__pw__node.html#gaea23ddf2322c57e3cca4a7d40144bda8", null ],
    [ "pw_node_send_command", "group__pw__node.html#ga6ac60f95cc0fdb6d769df30cce34901c", null ],
    [ "pw_node_set_param", "group__pw__node.html#ga03964e24225bdf9a290590cd30ad664a", null ],
    [ "pw_node_subscribe_params", "group__pw__node.html#ga5768e66e04bfef45e468df3e38158c93", null ],
    [ "PW_TYPE_INTERFACE_Node", "group__pw__node.html#ga125b3c8bae9656635dd9c24febbe221f", null ],
    [ "PW_VERSION_NODE", "group__pw__node.html#gae34dde148d3ae268808d68926a8a2da4", null ],
    [ "PW_VERSION_NODE_EVENTS", "pipewire_2src_2pipewire_2node_8h.html#a593a4f2610442e1956052f5c13de02f2", null ],
    [ "PW_VERSION_NODE_METHODS", "pipewire_2src_2pipewire_2node_8h.html#a0093e032db467e20f79767260fa1758e", null ],
    [ "pw_node_state", "group__pw__node.html#gac493839c0b0a1d0b935969f2e990a2df", [
      [ "PW_NODE_STATE_ERROR", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa316510257c8a6afc788c415cc3288ad2", null ],
      [ "PW_NODE_STATE_CREATING", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfaa73a63afebf017a0c0afdea192b1691c", null ],
      [ "PW_NODE_STATE_SUSPENDED", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa715c586abce5cbbc09db32145a51e82f", null ],
      [ "PW_NODE_STATE_IDLE", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa801ee69d0b0c9d30b12ff89daae9a075", null ],
      [ "PW_NODE_STATE_RUNNING", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfaa9c88f01497f82d9ffc4605dae27e93a", null ]
    ] ],
    [ "pw_node_info_free", "group__pw__node.html#ga0ee148738da978c59c3afaf91215db71", null ],
    [ "pw_node_info_update", "group__pw__node.html#ga576eec63e376281ca762c48b00b7eba3", null ],
    [ "pw_node_state_as_string", "group__pw__node.html#gafb0f3403157144c358f505b1163f658a", null ]
];

==> pipewire-docs-1%3A0.3.35-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/pipewire_2src_2pipewire_2node_8h.js <==
var pipewire_2src_2pipewire_2node_8h =
[
    [ "pw_node_add_listener", "group__pw__node.html#ga551b316bd8df6636cd863b82d3f006e3", null ],
    [ "PW_NODE_CHANGE_MASK_ALL", "pipewire_2src_2pipewire_2node_8h.html#a7f79a67df47a08661d622c1ca73571ea", null ],
    [ "PW_NODE_CHANGE_MASK_INPUT_PORTS", "pipewire_2src_2pipewire_2node_8h.html#a111891241c623bdfe86ba5e1811f374e", null ],
    [ "PW_NODE_CHANGE_MASK_OUTPUT_PORTS", "pipewire_2src_2pipewire_2node_8h.html#a91a6a1a257b75f8a6fd5eb6755447a59", null ],
    [ "PW_NODE_CHANGE_MASK_PARAMS", "pipewire_2src_2pipewire_2node_8h.html#a13f0cb22b45e8f81e709b84ff3b1fde7", null ],
    [ "PW_NODE_CHANGE_MASK_PROPS", "pipewire_2src_2pipewire_2node_8h.html#a3db541c9ec1c2245fe17402135979f2d", null ],
    [ "PW_NODE_CHANGE_MASK_STATE", "pipewire_2src_2pipewire_2node_8h.html#a9d39e0829f4a14185dc242d5c362b9de", null ],
    [ "pw_node_enum_params", "group__pw__node.html#ga3c668f349296e6fcbf3b294b92274f1f", null ],
    [ "PW_NODE_EVENT_INFO", "group__pw__node.html#gac3a4cf514e46d1e590ad45fd3e8d7813", null ],
    [ "PW_NODE_EVENT_NUM", "group__pw__node.html#ga3c78657690ffa3263238181bbe7073e4", null ],
    [ "PW_NODE_EVENT_PARAM", "group__pw__node.html#gaf8cda535f0a1e63b1074f859cf650525", null ],
    [ "pw_node_method", "group__pw__node.html#ga8f11f362e3c9cda9d9fba69ed37f9c9b", null ],
    [ "PW_NODE_METHOD_ADD_LISTENER", "group__pw__node.html#ga027e0d76dfb4448a29d718bec066b409", null ],
    [ "PW_NODE_METHOD_ENUM_PARAMS", "group__pw__node.html#ga5437fe007ac346f48f0f63fec8ca8b40", null ],
    [ "PW_NODE_METHOD_NUM", "group__pw__node.html#ga1977da2214d00db4a4d50202da3a2c35", null ],
    [ "PW_NODE_METHOD_SEND_COMMAND", "group__pw__node.html#ga3add61d46ad7b1daa86792cbeafc6090", null ],
    [ "PW_NODE_METHOD_SET_PARAM", "group__pw__node.html#ga6b2101857ce7cd58fa7024afa281a730", null ],
    [ "PW_NODE_METHOD_SUBSCRIBE_PARAMS", "group__pw__node.html#gaea23ddf2322c57e3cca4a7d40144bda8", null ],
    [ "pw_node_send_command", "group__pw__node.html#ga6ac60f95cc0fdb6d769df30cce34901c", null ],
    [ "pw_node_set_param", "group__pw__node.html#ga03964e24225bdf9a290590cd30ad664a", null ],
    [ "pw_node_subscribe_params", "group__pw__node.html#ga5768e66e04bfef45e468df3e38158c93", null ],
    [ "PW_TYPE_INTERFACE_Node", "group__pw__node.html#ga125b3c8bae9656635dd9c24febbe221f", null ],
    [ "PW_VERSION_NODE", "group__pw__node.html#gae34dde148d3ae268808d68926a8a2da4", null ],
    [ "PW_VERSION_NODE_EVENTS", "pipewire_2src_2pipewire_2node_8h.html#a593a4f2610442e1956052f5c13de02f2", null ],
    [ "PW_VERSION_NODE_METHODS", "pipewire_2src_2pipewire_2node_8h.html#a0093e032db467e20f79767260fa1758e", null ],
    [ "pw_node_state", "group__pw__node.html#gac493839c0b0a1d0b935969f2e990a2df", [
      [ "PW_NODE_STATE_ERROR", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa316510257c8a6afc788c415cc3288ad2", null ],
      [ "PW_NODE_STATE_CREATING", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfaa73a63afebf017a0c0afdea192b1691c", null ],
      [ "PW_NODE_STATE_SUSPENDED", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa715c586abce5cbbc09db32145a51e82f", null ],
      [ "PW_NODE_STATE_IDLE", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa801ee69d0b0c9d30b12ff89daae9a075", null ],
      [ "PW_NODE_STATE_RUNNING", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfaa9c88f01497f82d9ffc4605dae27e93a", null ]
    ] ],
    [ "pw_node_info_free", "group__pw__node.html#ga0ee148738da978c59c3afaf91215db71", null ],
    [ "pw_node_info_merge", "group__pw__node.html#ga31e36ebfd9bbef91cea1381889a7cf83", null ],
    [ "pw_node_info_update", "group__pw__node.html#ga98ac2a3a420d51c2afe18a0e79c18efe", null ],
    [ "pw_node_state_as_string", "group__pw__node.html#gabdc61213ac88ea6daf6141e0130d0430", null ]
];
